!======================================================================
!===>  PROGRAM TO PREDICT THE AMOUNT OF AUSTENITE PRODUCTS ************

!===>  (FERRITE,PEARLITE,BAINITE AND MARTENSITE) UPON ITS DECOMPOSITION 
!===>  DURING CONTINUOUS COOLING WITHIN THE "HAZ" OF FUSION WELDING ***

!===>  PROCESSES ******************************************************
!======================================================================
!===>  GLOBAL DECLARATION ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
!======================================================================  
!Mistake in DIFF pointed out by David Schroder, and corrected March 2014. 
MODULE GLOBAL
IMPLICIT NONE
REAL*8,PARAMETER :: R=8.31432
REAL*8 :: AE3,PS,BS,MS

REAL*8 :: A1,A2,A3,A4,A5,B1,B2,B3

REAL*8,DIMENSION(5) :: A
REAL*8,DIMENSION(3) :: B

REAL*8,DIMENSION(13) :: C
END MODULE GLOBAL
!======================================================================
!===>  PROGRAM MAIN   ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
!======================================================================  
PROGRAM MAIN
USE GLOBAL
IMPLICIT NONE

INTEGER :: I,ICOUNT,NMAX,PHASE
REAL*8 :: DT,TIME1,TIME2,TIMEAT,TIME_TRANS,TIME_SUM

REAL*8 :: C_ALPHA,C_GAMMA,GVALUE,TVALUE,XFE

REAL*8 :: VOLFERR,VOLPEAR,VOLBAIN,VOLBAIN_TRANS2

REAL*8 :: VOLFERR_TRANS,VOLPEAR_TRANS,VOLBAIN_TRANS,VOLMART_TRANS

REAL*8,EXTERNAL :: FUNCT_TEMPERATURE_TIME,FUNCT_GRAINSIZE_TIME

REAL*8,EXTERNAL :: RUNGE_KUTTA4,NEWTON_RAPHSON

!

!^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

OPEN(UNIT=55,FILE='haz_input.txt')

    !CHEMICAL COMPOSITION (%wt) OF ALLOYING ELEMENTS: NEED TO FOLLOW

	!THE SEQUENCE AS GIVEN BELOW.

    !  1    2    3    4    5    6    7   8   9    10   11   12   13

    !  C    Ni   Si   V    Mo   W    Mn  Cr  Cu   P    Al   As   Ti

	DO I=1,13

	   READ(55,*)C(I)

	END DO

    !COEFFICIENTS OF POLYNOMIAL EQUATION (OF ORDER 4) FOR %%%%%%%%%%%%%

    !TEMPERATURE vs TIME FOR THE COOLING PERIOD ONLY:

	!A(1)*t**4+A(2)*t**3+A(3)*t**2+A(4)*t+A(5) %%%%%%%%%%%%%%%%%%%%%%%% 

	DO I=1,5

	   READ(55,*)A(I)

	END DO

    !COEFFICIENTS OF POLYNOMIAL EQUATION (OF ORDER 3)  FOR %%%%%%%%%%%%

    !AVERAGE GRAIN SIZE vs TIME FOR THE COOLING PERIOD ONLY:		  

	!B(1)*t**2+B(2)*t+B(3) %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

	DO I=1,3

	   READ(55,*)B(I)

	END DO

CLOSE(55)

!^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

!INITIALISATION OF VARIABLES:

	  VOLFERR_TRANS=1.0E-10

	  VOLPEAR_TRANS=1.0E-10

	  VOLBAIN_TRANS=1.0E-10

	  VOLMART_TRANS=1.0E-10

	  ICOUNT=0

	  NMAX=10000 

!^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

OPEN(UNIT=111,FILE='haz_output.txt')

	  CALL PHASE_LIMIT_TEMPERATURE

	  WRITE(111,*)"    Time  ","   Temp. ","  Grain size "," Ferrite"&

	       & ,"   Pearlite  "," Bainite "," Martensite " 

!^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

!(1): AUSTENITE-FERRITE PHASE TRANSFORMATION **************************

	  PHASE=1

	  VOLFERR=1.0E-10

	  TVALUE=(AE3+273.16)

	  TIME1=NEWTON_RAPHSON(TVALUE)

	  TVALUE=(PS+273.16)

	  TIME2=NEWTON_RAPHSON(TVALUE)

	  TIME_TRANS=TIME2-TIME1

	  DT=TIME_TRANS/NMAX

	  TIMEAT=TIME1

	  VOLFERR_TRANS=0.0

      !

	  TVALUE=FUNCT_TEMPERATURE_TIME(TIMEAT)

      GVALUE=FUNCT_GRAINSIZE_TIME(TIMEAT)

  	  WRITE(111,116)TIMEAT,TVALUE,GVALUE,VOLFERR_TRANS &

		   & ,VOLPEAR_TRANS,VOLBAIN_TRANS,VOLMART_TRANS

  116 FORMAT(F10.3,F10.2,F10.1,4F10.4) 

	  !

	  DO I=1,NMAX

		IF(ICOUNT.GE.500)THEN

		  TVALUE=FUNCT_TEMPERATURE_TIME(TIMEAT)

          GVALUE=FUNCT_GRAINSIZE_TIME(TIMEAT)

		  WRITE(111,116)TIMEAT,TVALUE,GVALUE,VOLFERR_TRANS &

		     & ,VOLPEAR_TRANS,VOLBAIN_TRANS,VOLMART_TRANS

		  ICOUNT=0

		END IF

	    VOLFERR_TRANS=VOLFERR_TRANS+RUNGE_KUTTA4(DT,TIMEAT,VOLFERR &

	                 & ,PHASE)

	    TIME_SUM=TIMEAT+DT

		TIMEAT=TIME_SUM

		ICOUNT=ICOUNT+1

        TVALUE=FUNCT_TEMPERATURE_TIME(TIMEAT)

		C_GAMMA=((912.-(TVALUE-273.16)-15.2*C(2)+44.7*C(3)+104*C(4) &

		        & +31.5*C(5)+13.1*C(6)-30*C(7)-11*C(8)-20*C(9)+700 &

	            & *C(10)+400*C(11)+120*C(12)+400*C(13))/203.)**2

        C_ALPHA=(912.-(TVALUE-273.16))/8486.0

		XFE=(C_GAMMA-C(1))/(C_GAMMA-C_ALPHA)

		!WRITE(111,11)C(1),C_GAMMA,C_ALPHA,XFE

	 11 FORMAT(4F10.4)

		VOLFERR=VOLFERR_TRANS/XFE

		!WRITE(111,*)"I=",I,"   ","TIMEAT=",TIMEAT

	    !WRITE(111,12)TVALUE,VOLFERR,VOLFERR_TRANS

     12 FORMAT(' TVALUE= ',F10.4,' VOLFERR= ',F10.4, &

                 & ' VOLFERR_TRANS= ',F10.4 )

	  END DO

!^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

!(2): AUSTENITE-PEARLITE PHASE TRANSFORMATION *************************

	  PHASE=2

	  ICOUNT=0

	  VOLPEAR=1.0E-10

	  TVALUE=(PS+273.16)

	  TIME1=NEWTON_RAPHSON(TVALUE)

	  TVALUE=(BS+273.16)

	  TIME2=NEWTON_RAPHSON(TVALUE)

	  TIME_TRANS=TIME2-TIME1

	  DT=TIME_TRANS/NMAX

	  TIMEAT=TIME1

	  VOLPEAR_TRANS=0.0

      !

	  TVALUE=FUNCT_TEMPERATURE_TIME(TIMEAT)

      GVALUE=FUNCT_GRAINSIZE_TIME(TIMEAT)

  	  WRITE(111,116)TIMEAT,TVALUE,GVALUE,VOLFERR_TRANS &

		   & ,VOLPEAR_TRANS,VOLBAIN_TRANS,VOLMART_TRANS

	  !

	  DO I=1,NMAX

		IF(ICOUNT.GE.500)THEN

		  TVALUE=FUNCT_TEMPERATURE_TIME(TIMEAT)

          GVALUE=FUNCT_GRAINSIZE_TIME(TIMEAT)

		  WRITE(111,116)TIMEAT,TVALUE,GVALUE,VOLFERR_TRANS &

		     & ,VOLPEAR_TRANS,VOLBAIN_TRANS,VOLMART_TRANS

		  ICOUNT=0

		END IF

	    VOLPEAR_TRANS=VOLPEAR_TRANS+RUNGE_KUTTA4(DT,TIMEAT,VOLPEAR &

	                 & ,PHASE)

	    TIME_SUM=TIMEAT+DT

		TIMEAT=TIME_SUM

		ICOUNT=ICOUNT+1

		TVALUE=FUNCT_TEMPERATURE_TIME(TIMEAT)

		VOLPEAR=VOLPEAR_TRANS/(1.0-VOLFERR_TRANS)

		!WRITE(111,*)"I=",I,"   ","TIMEAT=",TIMEAT

	    !WRITE(111,13)TVALUE,VOLPEAR,VOLPEAR_TRANS

     13 FORMAT(' TVALUE= ',F10.4,' VOLPEAR= ',F10.4, &

                 & ' VOLPEAR_TRANS= ',F10.4 )

	  END DO

!^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

!(3): AUSTENITE-BAINITE PHASE TRANSFORMATION **************************

	  PHASE=3

	  ICOUNT=0

	  VOLBAIN=VOLPEAR_TRANS

	  TVALUE=(BS+273.16)

	  TIME1=NEWTON_RAPHSON(TVALUE)

	  TVALUE=(MS+273.16)

	  TIME2=NEWTON_RAPHSON(TVALUE)

	  TIME_TRANS=TIME2-TIME1

	  DT=TIME_TRANS/NMAX

	  TIMEAT=TIME1

	  VOLBAIN_TRANS=VOLPEAR_TRANS

	  VOLBAIN_TRANS2=0.0

      !

	  TVALUE=FUNCT_TEMPERATURE_TIME(TIMEAT)

      GVALUE=FUNCT_GRAINSIZE_TIME(TIMEAT)

  	  WRITE(111,116)TIMEAT,TVALUE,GVALUE,VOLFERR_TRANS &

		   & ,VOLPEAR_TRANS,VOLBAIN_TRANS2,VOLMART_TRANS

	  !

	  DO I=1,NMAX

		IF(ICOUNT.GE.500)THEN

		  TVALUE=FUNCT_TEMPERATURE_TIME(TIMEAT)

          GVALUE=FUNCT_GRAINSIZE_TIME(TIMEAT)

		  WRITE(111,116)TIMEAT,TVALUE,GVALUE,VOLFERR_TRANS &

		     & ,VOLPEAR_TRANS,VOLBAIN_TRANS2,VOLMART_TRANS

		  ICOUNT=0

		END IF

	    VOLBAIN_TRANS=VOLBAIN_TRANS+RUNGE_KUTTA4(DT,TIMEAT &

		             & ,VOLBAIN_TRANS,PHASE)

	    TIME_SUM=TIMEAT+DT

		TIMEAT=TIME_SUM

		ICOUNT=ICOUNT+1

		TVALUE=FUNCT_TEMPERATURE_TIME(TIMEAT)

		VOLBAIN_TRANS2=(VOLBAIN_TRANS-VOLPEAR) &

		             & *(1.0-VOLFERR_TRANS-VOLPEAR_TRANS)

		IF(VOLBAIN_TRANS2.LT.0.0)VOLBAIN_TRANS2=0.0

		!WRITE(111,*)"I=",I,"   ","TIMEAT=",TIMEAT

		!WRITE(111,14)TVALUE,VOLBAIN_TRANS2

     14 FORMAT(' TVALUE= ',F10.4,' VOLBAIN_TRANS2= ',F10.4 )

		IF(VOLBAIN_TRANS.GE.0.99999) GOTO 666

	  END DO

!^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

!(4): AUSTENITE-MARTENSITE PHASE TRANSFORMATION ***********************

666 CONTINUE

	  VOLMART_TRANS=(1.0-VOLFERR_TRANS-VOLPEAR_TRANS-VOLBAIN_TRANS2)

!^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

!PRINT STATEMENTS FOR THE OVERALL TRANSFORMATION OF AUSTENITE PRODUCTS

WRITE(111,*)"----------------------------------------------------------"

WRITE(111,118)VOLFERR_TRANS*100.0,VOLPEAR_TRANS*100.0

118 FORMAT(' FERRITE (%) =',F10.2,' PEARLITE   (%) =',F10.2)

WRITE(111,*)

WRITE(111,119)VOLBAIN_TRANS2*100.0,VOLMART_TRANS*100.0

119 FORMAT(' BAINITE (%) =',F10.2,' MARTENSITE (%) =',F10.2)

WRITE(111,*)"----------------------------------------------------------"

!

CLOSE(111)

!

WRITE(*,*)"PROGRAM TERMINATED"

END PROGRAM MAIN
!=======================================================================     
!===>  SUBROUTINE PHASE_LIMIT_TEMPERATURE TO CALCULATE THE PHASE *******

!===>  LIMITING TEMPERATURES BASED ON THE CHEMISRY OF HARDENABLE SREELS*

!===>  (PLAIN CARBON & LOW-ALLOY STEELS) IN THE BASE METAL *************

!=======================================================================
SUBROUTINE PHASE_LIMIT_TEMPERATURE
USE GLOBAL
IMPLICIT NONE
!

      WRITE(111,*)"------------------------------------------------------"

      WRITE(111,*)"*************  PHASE LIMITING TEMPERATURES ***********"
!PARA EQUILIBRIUM TEMPERATURE (Deg. C)
      AE3=912-203*SQRT(C(1))-15.2*C(2)+44.7*C(3)+104*C(4)+31.5*C(5) &
         & +13.1*C(6)-30*C(7)-11*C(8)-20*C(9)+700*C(10)+400*C(11) &
         & +120*C(12)+400*C(13)
      WRITE(111,112)AE3 

  112 FORMAT(' Ae3 = ',F10.1,' (Deg. C)')
!EUTECTOID TEMPERATURE (Deg. C)
      PS=723-10.7*C(7)-16.9*C(2)+29*C(3)+16.9*C(8)+290*C(12)+6.4*c(6)
      WRITE(111,113)PS 
  113 FORMAT(' Ps  = ',F10.1,' (Deg. C)')

!BAINITE START TEMPERATURE (Deg. C)
      BS=656-58*C(1)-35*C(7)-75*C(3)-15*C(2)-34*C(8)-41*C(5)
      WRITE(111,114)BS    
  114 FORMAT(' Bs  = ',F10.1,' (Deg. C)')

!MARETENSITE START TEMPERATURE (Deg. C)
      MS=561-474*C(1)-33*C(7)-17*C(2)-17*C(8)-21*C(5)
      WRITE(111,115)MS
  115 FORMAT(' Ms  = ',F10.1,' (Deg. C)')

      WRITE(111,*)"------------------------------------------------------"

!STOP
END SUBROUTINE PHASE_LIMIT_TEMPERATURE
!=======================================================================     
FUNCTION RUNGE_KUTTA4(DT,TIMEAT,VOLFRAC,PHASE)

IMPLICIT NONE

INTEGER,INTENT(IN) :: PHASE

REAL*8,INTENT(IN) :: DT,TIMEAT,VOLFRAC

REAL*8 :: K1,K2,K3,K4,KAVER,RUNGE_KUTTA4

REAL*8,EXTERNAL :: FUNCT_PHASE

!

	  K1=DT*FUNCT_PHASE(TIMEAT,VOLFRAC,PHASE)

	  K2=DT*FUNCT_PHASE((TIMEAT+DT/2),(VOLFRAC+K1/2),PHASE)

	  K3=DT*FUNCT_PHASE((TIMEAT+DT/2),(VOLFRAC+K2/2),PHASE)  

	  K4=DT*FUNCT_PHASE((TIMEAT+DT),(VOLFRAC+K3),PHASE)  

	  KAVER=(K1+2.*K2+2.*K3+K4)/6

	  RUNGE_KUTTA4=KAVER

!

END FUNCTION RUNGE_KUTTA4

!======================================================================= 

FUNCTION FUNCT_PHASE(TIMEAT,VOLFRAC,PHASE)
USE GLOBAL
IMPLICIT NONE
INTEGER,INTENT(IN) :: PHASE

INTEGER :: ASTM_GSN

REAL*8,INTENT(IN) :: TIMEAT,VOLFRAC 
REAL*8 :: COM,DIFF,FXCI,GVALUE,TVALUE,UNDERCOOL 
REAL*8 :: BB,POWERM,POWERP,XM,XP,FUNCT_PHASE

REAL*8,EXTERNAL :: FUNCT_GRAINSIZE_TIME,FUNCT_TEMPERATURE_TIME
!

SELECT CASE(PHASE)

    CASE(1)

      TVALUE=FUNCT_TEMPERATURE_TIME(TIMEAT) 

	  COM=59.6*C(7)+1.45*C(2)+67.7*C(8)+244.*C(5) 

      UNDERCOOL=(AE3+273.16)-TVALUE

      GVALUE=FUNCT_GRAINSIZE_TIME(TIMEAT) 

	  ASTM_GSN=(LOG(2.)+(LOG((254.*254.)/GVALUE**2)))/LOG(2.)

	  BB=((2.**((ASTM_GSN-1.)/2.))*(UNDERCOOL**3) &

	    & *EXP((-23000.*4.186)/(R*TVALUE)))/COM 
	  POWERM=(2.*(1.-VOLFRAC)/3.)

      XM=VOLFRAC**POWERM

	  POWERP=(2.*VOLFRAC/3.) 
	  IF(VOLFRAC.GT.0.99999)THEN

	    XP=0.0

	  ELSE

	    XP=(1.-VOLFRAC)**POWERP 

	  END IF
      FUNCT_PHASE=BB*XM*XP 

	CASE(2)

	  XM=0.0

	  XP=1.0

      TVALUE=FUNCT_TEMPERATURE_TIME(TIMEAT)
C mistake in equation below corrected, C(8) replaced C(1). 

      DIFF=(1./(EXP((-27500.*4.186)/(R*TVALUE))) &

	      & +(0.01*C(8)+0.52*C(5)) &

          & /(EXP((-37000.*4.186)/(R*TVALUE))))

      DIFF=1./DIFF    

	  UNDERCOOL=(PS+273.16)-TVALUE

      GVALUE=FUNCT_GRAINSIZE_TIME(TIMEAT) 

      ASTM_GSN=(LOG(2.)+(LOG((254.*254.)/GVALUE**2)))/LOG(2.)

      BB=((2.**((ASTM_GSN-1.)/2.))*(UNDERCOOL**3)*DIFF) &

	    & /(1.79+5.42*(C(8)+C(5)+4*C(5)*C(2)))    

	  POWERM=(2.*(1.-VOLFRAC)/3.)

	  IF(VOLFRAC.LT.0.00001)THEN

	    XM=0.0

	  ELSE

        XM=VOLFRAC**POWERM

	  END IF

	  IF(VOLFRAC.GT.0.99999)THEN

	    XM=1.0

	  ELSE

        XM=VOLFRAC**POWERM

	  END IF

	  POWERP=(2.*VOLFRAC/3.) 

	  IF(VOLFRAC.GT.0.99999)THEN

	    XP=0.0

	  ELSE

	    XP=(1.-VOLFRAC)**POWERP 

	  END IF

      FUNCT_PHASE=BB*XM*XP

	CASE(3)

      TVALUE=FUNCT_TEMPERATURE_TIME(TIMEAT)

      FXCI=EXP(VOLFRAC**2*(1.9*C(1)+2.5*C(7)+0.9*C(2)+1.7*C(8) &

	      & +4.*C(5)-2.6))

      UNDERCOOL=(BS+273.16)-TVALUE

      GVALUE=FUNCT_GRAINSIZE_TIME(TIMEAT) 

	  ASTM_GSN=(LOG(2.)+(LOG((254.*254.)/GVALUE**2)))/LOG(2.)

	  BB=((2.**((ASTM_GSN-1.)/2.))*(UNDERCOOL**2) &

	    & *EXP((-27500.*4.186)/(R*TVALUE))) &

	    & /((2.34+10.1*C(1)+3.8*C(8)+19.*C(5))*1.0E-4*FXCI)

	  POWERM=(2.*(1.-VOLFRAC)/3.)

	  IF(VOLFRAC.LT.0.00001)THEN

	    XM=0.0

	  ELSE

        XM=VOLFRAC**POWERM

	  END IF

	  POWERP=(2.*VOLFRAC/3.) 

	  IF(VOLFRAC.GT.0.99999)THEN

	    XP=1.0

	  ELSE

	    XP=(1.-VOLFRAC)**POWERP 

	  END IF

      FUNCT_PHASE=BB*XM*XP

END SELECT
!

END FUNCTION FUNCT_PHASE

!=======================================================================     

FUNCTION FUNCT_TEMPERATURE_TIME(TIMEAT)

USE GLOBAL

IMPLICIT NONE

REAL*8,INTENT(IN) :: TIMEAT

REAL*8 :: TVALUE,FUNCT_TEMPERATURE_TIME

!

	  TVALUE=(A(1)*TIMEAT**4)+(A(2)*TIMEAT**3)+(A(3)*TIMEAT**2) &

	        & +(A(4)*TIMEAT)+A(5)

	  FUNCT_TEMPERATURE_TIME=TVALUE

!

END FUNCTION FUNCT_TEMPERATURE_TIME

!======================================================================= 

FUNCTION FUNCT_GRAINSIZE_TIME(TIMEAT)

USE GLOBAL

IMPLICIT NONE

REAL*8,INTENT(IN) :: TIMEAT

REAL*8 :: GVALUE,FUNCT_GRAINSIZE_TIME

!

	  GVALUE=(B(1)*TIMEAT**2)+(B(2)*TIMEAT)+B(3)

	  FUNCT_GRAINSIZE_TIME=GVALUE

!

END FUNCTION FUNCT_GRAINSIZE_TIME

!=======================================================================

FUNCTION NEWTON_RAPHSON(TVALUE)

USE GLOBAL

IMPLICIT NONE

INTEGER,PARAMETER :: IMAX=500

INTEGER :: I

REAL*8,PARAMETER :: EPSI=1.0E-6

REAL*8,INTENT(IN) :: TVALUE

REAL*8 :: X0,X1,FT,FT1,NEWTON_RAPHSON

!

	  X0=0.1 !INITIAL GUESSED VALUE

	  DO I=1,IMAX !ITERATION LOOP: BEGINS HERE

	  	 FT=(A(1)*X0**4)+(A(2)*X0**3)+(A(3)*X0**2)+(A(4)*X0) &

		   & +(A(5)-TVALUE)

		 FT1=(4.*A(1)*X0**3)+(3.*A(2)*X0**2)+(2.*A(3)*X0)+A(4)

	  	 IF(FT1.EQ.0.0)THEN

		   WRITE(*,*)"FAILED: SOLUTION OF A FUNCTION ->NEWTON-RAPHSON" 

		   WRITE(*,*)"FUNCTION MUST BE CONTINUOUS & HAS CONT. DERIVATIVE" 

		   STOP !DO NOT DELETE THIS

		 ELSE

		   X1=X0-(FT/FT1)

		   IF(ABS(X1-X0).LT.EPSI)THEN

			 NEWTON_RAPHSON=X1

			 GOTO 999

		   ELSE

		   	 X0=X1

		   END IF

		 END IF

	  END DO !ITERATION LOOP: ENDS HERE

	  IF(I.EQ.IMAX)THEN

		WRITE(*,*)"FAILED: INCREASE NO. OF ITERATIONS-->NEWTON-RAPHSON"

	  END IF

  999 CONTINUE

!

END FUNCTION NEWTON_RAPHSON

!=======================================================================

!===>  END OF THE CODE *************************************************
!===>  HAVE A NICE TIME ************************************************
!=======================================================================
